pycocoa.runtime.ObjCBoundClassMethod

Package pycocoa :: Module runtime :: Class ObjCBoundClassMethod |
[frames] | no frames]

# Class ObjCBoundClassMethod

              object --+
                       |
    internals._Objectype --+
                           |
                   _ObjCBase --+
                               |
                 ObjCBoundMethod --+
                                   |
                                  ObjCBoundClassMethod

Python wrapper for a bound ObjC class method, only to distinguish bound class from bound instance methods.

Instance Methods
Inherited from `ObjCBoundMethod`: `__call__`, `__init__`, `__str__` Inherited from `_ObjCBase`: `__repr__` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `ObjCBoundMethod`: `inst`, `method`, `name`, `objc_id` Inherited from `_ObjCBase`: `description` Inherited from `internals._Objectype`: `typename` Inherited from `object`: `__class__`